package Sah::Schemas::YouTube;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-03-11'; # DATE
our $DIST = 'Sah-Schemas-YouTube'; # DIST
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Sah schemas related to YouTube

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::YouTube - Sah schemas related to YouTube

=head1 VERSION

This document describes version 0.003 of Sah::Schemas::YouTube (from Perl distribution Sah-Schemas-YouTube), released on 2020-03-11.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-YouTube>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-YouTube>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-YouTube>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
